@@ -2,16 +2,17 @@
 from __future__ import annotations
 
 import cmath
+from collections.abc import Iterable
 from dataclasses import dataclass
-from typing import Any, Optional, SupportsIndex
+from typing import Optional, SupportsIndex, Union
 
 
-def convert_angle(angle: float, /, unit: str):
+def angle(angle: float, /, unit: str):
     """Convert an angle to radians."""
     unit = unit.lower()
     if unit in {"d", "deg", "degrees", "degree", "°"}:
         return angle * cmath.tau / 360
-    if unit in {"r", "", None, "rad", "radian", "radians"}:
+    if unit in {"r", "rad", "radian", "radians"}:
         return angle
     if unit in {"g", "grad", "gradians", "gradian", "gons", "gon", "grades", "grade"}:
         return angle * cmath.tau / 400
@@ -21,33 +22,25 @@ def convert_angle(angle: float, /, unit: str):
         return angle * cmath.tau / 1296000
     if unit in {"turn", "turns"}:
         return angle * cmath.tau
-    raise ValueError(f"Invalid angle unit: '{unit}'")
+    raise ValueError(f"invalid angle unit: '{unit}'")
 
 
-def _object_to_xy(obj: Any, /) -> tuple:
-    """Convert an object to an (x, y) tuple."""
-    # Deal with objects with x and y attributes
-    try:
-        return (obj.x, obj.y)
-    except AttributeError:
-        pass
-    # Deal with iterables
+def _iterable_to_complex(obj: Iterable[float], /) -> complex:
+    """Convert an iterable to an (x, y) tuple."""
     try:
         iterable = iter(obj)
-        try:
-            x = next(iterable)
-            y = next(iterable)
-        except StopIteration:
-            raise ValueError("Iterable is too short to create Vector")
-        try:
-            next(iterable)
-            raise ValueError("Iterable is too long to create Vector")
-        except StopIteration:
-            return (x, y)
     except TypeError:
-        raise TypeError(
-            "Single argument Vector must be Vector, complex, iterable or have x and y attributes"
-        )
+        raise TypeError("single argument Vector must be Vector, complex or iterable")
+    try:
+        x = next(iterable)
+        y = next(iterable)
+    except StopIteration:
+        raise ValueError("iterable is too short to create Vector")
+    try:
+        next(iterable)
+        raise ValueError("iterable is too long to create Vector")
+    except StopIteration:
+        return complex(x, y)
 
 
 @dataclass(frozen=True, init=False, repr=False)
@@ -57,51 +50,27 @@ class Vector:
     _complex: complex
 
     def __init__(
-        self,
-        x: Any = None,
-        y: Optional[float] = None,
-        *,
-        r: Optional[float] = None,
-        theta: Optional[float] = None,
-        angle_unit: str = "rad",
+        self, x: Union[complex, float, Iterable[float]], y: Optional[float] = None
     ):
-        if r is None and theta is None:
-            if y is None:
-                if isinstance(x, complex):
-                    object.__setattr__(self, "_complex", x)
-                else:
-                    # Create Vector from a single argument using the
-                    # implementation _complex provides
-                    try:
-                        object.__setattr__(self, "_complex", complex(x))
-                    except TypeError:
-                        # Get x and y values using our implementation
-                        object.__setattr__(self, "_complex", complex(*_object_to_xy(x)))
+        """Create a Vector from a single argument or x, y pair."""
+        if y is None:
+            if isinstance(x, complex):
+                object.__setattr__(self, "_complex", x)
             else:
-                if x is None:
-                    raise ValueError("Must give x to create Vector if y is given")
-                # Create Vector from x and y
-                try:
-                    object.__setattr__(self, "_complex", complex(x, y))
-                except TypeError:
-                    raise TypeError("x and y values must be numeric to create Vector")
-            return
+                object.__setattr__(self, "_complex", _iterable_to_complex(x))
+        else:
+            # Create Vector from x and y
+            try:
+                object.__setattr__(self, "_complex", complex(x, y))
+            except TypeError:
+                raise TypeError("x and y values must be numeric to create Vector")
 
-        if x is not None or y is not None:
-            raise ValueError(
-                "Cannot create Vector from mixed rectangular and polar arguments"
-            )
-
-        # Create Vector from polar arguments
+    @staticmethod
+    def from_polar(r: float, theta: float):
+        """Create a Vector from polar coordinates."""
         if r == 0:
-            return Vector(0)
-        if r is None or theta is None:
-            raise ValueError(
-                "must provide both r and theta to create Vector from polar"
-            )
-        object.__setattr__(
-            self, "_complex", cmath.rect(r, convert_angle(theta, angle_unit))
-        )
+            return Vector(0, 0)
+        return Vector(cmath.rect(r, theta))
 
     def dot(self, other: Vector, /) -> float:
         """Return the dot product of self and other."""
@@ -132,13 +101,12 @@ class Vector:
         """
         return Vector(complex(-self._complex.imag, self._complex.real))
 
-    def rotate(self, angle: float, /, unit="rad") -> Vector:
+    def rotate(self, angle: float) -> Vector:
         """
         Return a self, rotated by angle anticlockwise.
 
         Use negative angles for a clockwise rotation.
         """
-        angle = convert_angle(angle, unit)
         return Vector(cmath.rect(self.r, self.theta + angle))
 
     def hat(self, /) -> Vector:
@@ -154,6 +122,7 @@ class Vector:
         return cmath.polar(self._complex)
 
     def round(self, ndigits: int = 0, /) -> tuple:
+        """Get the vector with both components rounded, as a tuple."""
         return (round(self._complex.real, ndigits), round(self._complex.imag, ndigits))
 
     def __str__(self, /):
@@ -170,9 +139,6 @@ class Vector:
     def __getitem__(self, key: SupportsIndex, /) -> float:
         return self.rec()[key]
 
-    def __contains__(self, item: float, /):
-        return item == self._complex.real or item == self._complex.imag
-
     def __iter__(self, /):
         yield self._complex.real
         yield self._complex.imag
